@@ -1,10 +1,10 @@
        type(epDirec)::  DCInp
        type(epPos)::   PosInp
 
-        complex*16 Xrange, Yrange, Zrange
+        complex(8):: Xrange, Yrange, Zrange
 	real*8  E0Max
 	real*8 Hwhm, ProfR
-        complex*16  CosNormal
+        complex(8)::  CosNormal
         logical LogIr
         character*12 InputA
         character*8 InputP
